@@ -4,10 +4,10 @@ from zope.publisher.browser import BrowserView
 INLINE_STYLES = {'width': 'map_width',
                  'height': 'map_height'}
 
+
 class CollectiveGeoMacros(BrowserView):
     template = ViewPageTemplateFile('collectivegeo_macros.pt')
 
-
     def __getitem__(self, key):
         return self.template.macros[key]
 
@@ -16,7 +16,7 @@ class CollectiveGeoMacros(BrowserView):
         """
         inline_css = ''
         geofeaturestyle = \
-                self.context.restrictedTraverse('@@geofeaturestyle-view');
+                self.context.restrictedTraverse('@@geofeaturestyle-view')
         for style in INLINE_STYLES:
             value = getattr(geofeaturestyle, INLINE_STYLES[style], None)
             if value:
@@ -24,3 +24,11 @@ class CollectiveGeoMacros(BrowserView):
 
         return inline_css or None
 
+    @property
+    def location(self):
+        try:
+            location = self.context.getLocation()
+        except AttributeError:
+            return u''
+        if isinstance(location, str):
+            return location.decode('utf8')
