@@ -8,8 +8,7 @@ from Products.PloneTestCase.layer import onsetup
 
 @onsetup
 def setup_product():
-    """
-       Set up the package and its dependencies.
+    """Set up the package and its dependencies.
     """
 
     fiveconfigure.debug_mode = True
@@ -20,7 +19,11 @@ def setup_product():
 
 
 setup_product()
-ptc.setupPloneSite(products=['collective.geo.mapwidget'])
+ptc.setupPloneSite(
+    extension_profiles=('collective.geo.mapwidget:default',
+                        'collective.geo.settings:default',
+                        'collective.geo.mapwidget:default',)
+)
 
 
 class TestCase(ptc.PloneTestCase):
@@ -28,8 +31,12 @@ class TestCase(ptc.PloneTestCase):
 
 
 class FunctionalTestCase(ptc.FunctionalTestCase):
-    
+
     def afterSetUp(self):
+
         from collective.geo.settings.utils import geo_settings
-        geo_settings(self.portal).default_layers = [u'osm', u'google_ter', u'google_hyb', 
-                                         u'google_sat', u'google_map']
+        geo_settings(self.portal).default_layers = [u'osm',
+                                                    u'google_ter',
+                                                    u'google_hyb',
+                                                    u'google_sat',
+                                                    u'google_map']
